==> v8.3.zip: ru_twords_ru_tw/bible/other/gold.md <==
# золото, золотой,

## Определение:

Золото — благородный металл жёлтого цвета, отличающийся мягкостью и пластичностью. В древности он использовался для изготовления ювелирных украшений и храмовых принадлежностей. По сравнению со всеми другими металлами, в древние времена золото считалось самым ценным.

* В библейские времена многие предметы покрывали тонким слоем золота или отливали из чистого золота.
* Среди таких вещей были ювелирные украшения — серьги, браслеты и пр., а также идолы, жертвенники и другие храмовые принадлежности. Ковчег завета и посуда, используемая священниками в скинии и в храме, также были отлиты из золота.
* В ветхозаветные времена золото использовалось в торговле как универсальное средство обмена. Для определения его количества торговцы взвешивали его на весах.
* Позже люди начали чеканить монеты из золота, серебра и других металлов.
* Предметы, которые не являются золотыми, но покрытые тонким слоем золота, называются позолоченными.
* Золотистый — это цвет, напоминающий золото.

(См. также: [алтарь](../kt/altar.md), [ковчег завета](../kt/arkofthecovenant.md), [ложный бог](../kt/falsegod.md), [серебро](../other/silver.md), [скиния](../kt/tabernacle.md), [храм](../kt/temple.md))

## Ссылки на библейский текст:

* [1 Пет. 1:6-7](rc://*/tn/help/1pe/01/06)
* [1 Тим. 2:8-10](rc://*/tn/help/1ti/02/08)
* [2 Пар. 1:14-15](rc://*/tn/help/2ch/01/14)
* [Деян. 3:4-6](rc://*/tn/help/act/03/04)
* [Дан. 2:31-33](rc://*/tn/help/dan/02/31)

## Данные о слове:

* Номера Стронга: H1220, H1222, H1722, H2091, H2742, H3800, H4062, H5458, H6884, H6885, G5552, G5553, G5554, G5557

==> v9.2.zip: ru_twords_ru_tw/bible/other/gold.md <==
# золото, золотой,

## Определение:

Золото — благородный металл жёлтого цвета, отличающийся мягкостью и пластичностью. В древности он использовался для изготовления ювелирных украшений и храмовых принадлежностей. По сравнению со всеми другими металлами, в древние времена золото считалось самым ценным.

* В библейские времена многие предметы покрывали тонким слоем золота или отливали из чистого золота.
* Среди таких вещей были ювелирные украшения — серьги, браслеты и пр., а также идолы, жертвенники и другие храмовые принадлежности. Ковчег завета и посуда, используемая священниками в скинии и в храме, также были отлиты из золота. 
* В ветхозаветные времена золото использовалось в торговле как универсальное средство обмена. Для определения его количества торговцы взвешивали его на весах. 
* Позже люди начали чеканить монеты из золота, серебра и других металлов.
* Предметы, которые не являются золотыми, но покрытые тонким слоем золота, называются позолоченными.
* Золотистый — это цвет, напоминающий золото.


(См. также: [алтарь](../kt/altar.md), [ковчег завета](../kt/arkofthecovenant.md), [ложный бог](../kt/falsegod.md), [серебро](../other/silver.md), [скиния](../kt/tabernacle.md), [храм](../kt/temple.md))

## Ссылки на библейский текст:

* [1 Пет. 1:6-7](rc://ru/tn/help/1pe/01/06)
* [1 Тим. 2:8-10](rc://ru/tn/help/1ti/02/08)
* [2 Пар. 1:14-15](rc://ru/tn/help/2ch/01/14)
* [Деян. 3:4-6](rc://ru/tn/help/act/03/04)
* [Дан. 2:31-33](rc://ru/tn/help/dan/02/31)

## Данные о слове:

* Номера Стронга: H1220, H1222, H1722, H2091, H2742, H3800, H4062, H5458, H6884, H6885, G5552, G5553, G5554, G5557
